@@ -918,12 +918,16 @@ fn partial_eq() {
 
 #[test]
 fn partial_ord() {
-  // TODO: add more here.
   assert!(staticvec![1] < staticvec![2]);
   assert!(staticvec![1] > []);
   assert!(staticvec![1] <= &staticvec![2]);
   assert!(staticvec![1] >= &[]);
   assert!(staticvec![1] > &mut []);
+  assert!(staticvec![vec![1], vec![2]] < staticvec![vec![1], vec![2], vec![3]]);
+  assert!(staticvec![vec![1]] > []);
+  assert!(staticvec![vec![1]] <= &staticvec![vec![2]]);
+  assert!(staticvec![vec![1]] >= &[]);
+  assert!(staticvec![vec![1]] > &mut []);
 }
 
 #[test]
